pub struct StringInfo {
pub text: String,
pub node_name: String,
pub line_number: usize,
pub file_name: String,
pub is_implicit_tag: bool,
pub metadata: Vec<String>,
}Expand description
Information about a string. Stored inside a string table, which is produced from the Compiler.
You do not create instances of this class yourself. They are
generated by the Compiler.
Fields
text: StringThe original text of the string.
node_name: StringThe name of the node that this string was found in.
line_number: usizeThe 1-indexed line number at which this string was found in the file.
file_name: StringThe name of the file this string was found in.
is_implicit_tag: boolIndicates whether this string’s line ID was implicitly generated.
Implicitly generated line IDs are not guaranteed to remain the same across multiple compilations. To ensure that a line ID remains the same, you must define it by adding a line tag to the line.
metadata: Vec<String>The metadata (i.e. hashtags) associated with this string.
This array will contain any hashtags associated with this
string besides the #line: hashtag.